@@ -1,10 +1,9 @@
 # Natural Language Toolkit: K-Means Clusterer
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Trevor Cohn <tacohn@cs.mu.oz.au>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
-from __future__ import print_function, unicode_literals, division
 
 import copy
 import random
@@ -17,10 +16,8 @@ except ImportError:
 
 
 from nltk.cluster.util import VectorSpaceClusterer
-from nltk.compat import python_2_unicode_compatible
 
 
-@python_2_unicode_compatible
 class KMeansClusterer(VectorSpaceClusterer):
     """
     The K-means clusterer starts with k arbitrary chosen means then allocates
@@ -83,12 +80,12 @@ class KMeansClusterer(VectorSpaceClusterer):
 
     def cluster_vectorspace(self, vectors, trace=False):
         if self._means and self._repeats > 1:
-            print('Warning: means will be discarded for subsequent trials')
+            print("Warning: means will be discarded for subsequent trials")
 
         meanss = []
         for trial in range(self._repeats):
             if trace:
-                print('k-means trial', trial)
+                print("k-means trial", trial)
             if not self._means or trial > 1:
                 self._means = self._rng.sample(list(vectors), self._num_means)
             self._cluster_vectorspace(vectors, trace)
@@ -126,7 +123,7 @@ class KMeansClusterer(VectorSpaceClusterer):
                     clusters[index].append(vector)
 
                 if trace:
-                    print('iteration')
+                    print("iteration")
                 # for i in range(self._num_means):
                 # print '  mean', i, 'allocated', len(clusters[i]), 'vectors'
 
@@ -178,9 +175,9 @@ class KMeansClusterer(VectorSpaceClusterer):
             return centroid / (1 + len(cluster))
         else:
             if not len(cluster):
-                sys.stderr.write('Error: no centroid defined for empty cluster.\n')
+                sys.stderr.write("Error: no centroid defined for empty cluster.\n")
                 sys.stderr.write(
-                    'Try setting argument \'avoid_empty_clusters\' to True\n'
+                    "Try setting argument 'avoid_empty_clusters' to True\n"
                 )
                 assert False
             centroid = copy.copy(cluster[0])
@@ -189,7 +186,7 @@ class KMeansClusterer(VectorSpaceClusterer):
             return centroid / len(cluster)
 
     def __repr__(self):
-        return '<KMeansClusterer means=%s repeats=%d>' % (self._means, self._repeats)
+        return "<KMeansClusterer means=%s repeats=%d>" % (self._means, self._repeats)
 
 
 #################################################################################
@@ -206,9 +203,9 @@ def demo():
     clusterer = KMeansClusterer(2, euclidean_distance, initial_means=means)
     clusters = clusterer.cluster(vectors, True, trace=True)
 
-    print('Clustered:', vectors)
-    print('As:', clusters)
-    print('Means:', clusterer.means())
+    print("Clustered:", vectors)
+    print("As:", clusters)
+    print("Means:", clusterer.means())
     print()
 
     vectors = [numpy.array(f) for f in [[3, 3], [1, 2], [4, 2], [4, 0], [2, 3], [3, 1]]]
@@ -218,17 +215,17 @@ def demo():
 
     clusterer = KMeansClusterer(2, euclidean_distance, repeats=10)
     clusters = clusterer.cluster(vectors, True)
-    print('Clustered:', vectors)
-    print('As:', clusters)
-    print('Means:', clusterer.means())
+    print("Clustered:", vectors)
+    print("As:", clusters)
+    print("Means:", clusterer.means())
     print()
 
     # classify a new vector
     vector = numpy.array([3, 3])
-    print('classify(%s):' % vector, end=' ')
+    print("classify(%s):" % vector, end=" ")
     print(clusterer.classify(vector))
     print()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     demo()
