@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Corpus Readers
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -66,238 +66,238 @@ from nltk.corpus.util import LazyCorpusLoader
 from nltk.corpus.reader import *
 
 abc = LazyCorpusLoader(
-    'abc',
+    "abc",
     PlaintextCorpusReader,
-    r'(?!\.).*\.txt',
-    encoding=[('science', 'latin_1'), ('rural', 'utf8')],
+    r"(?!\.).*\.txt",
+    encoding=[("science", "latin_1"), ("rural", "utf8")],
 )
-alpino = LazyCorpusLoader('alpino', AlpinoCorpusReader, tagset='alpino')
+alpino = LazyCorpusLoader("alpino", AlpinoCorpusReader, tagset="alpino")
 brown = LazyCorpusLoader(
-    'brown',
+    "brown",
     CategorizedTaggedCorpusReader,
-    r'c[a-z]\d\d',
-    cat_file='cats.txt',
-    tagset='brown',
+    r"c[a-z]\d\d",
+    cat_file="cats.txt",
+    tagset="brown",
     encoding="ascii",
 )
 cess_cat = LazyCorpusLoader(
-    'cess_cat',
+    "cess_cat",
     BracketParseCorpusReader,
-    r'(?!\.).*\.tbf',
-    tagset='unknown',
-    encoding='ISO-8859-15',
+    r"(?!\.).*\.tbf",
+    tagset="unknown",
+    encoding="ISO-8859-15",
 )
 cess_esp = LazyCorpusLoader(
-    'cess_esp',
+    "cess_esp",
     BracketParseCorpusReader,
-    r'(?!\.).*\.tbf',
-    tagset='unknown',
-    encoding='ISO-8859-15',
+    r"(?!\.).*\.tbf",
+    tagset="unknown",
+    encoding="ISO-8859-15",
 )
-cmudict = LazyCorpusLoader('cmudict', CMUDictCorpusReader, ['cmudict'])
-comtrans = LazyCorpusLoader('comtrans', AlignedCorpusReader, r'(?!\.).*\.txt')
+cmudict = LazyCorpusLoader("cmudict", CMUDictCorpusReader, ["cmudict"])
+comtrans = LazyCorpusLoader("comtrans", AlignedCorpusReader, r"(?!\.).*\.txt")
 comparative_sentences = LazyCorpusLoader(
-    'comparative_sentences',
+    "comparative_sentences",
     ComparativeSentencesCorpusReader,
-    r'labeledSentences\.txt',
-    encoding='latin-1',
+    r"labeledSentences\.txt",
+    encoding="latin-1",
 )
 conll2000 = LazyCorpusLoader(
-    'conll2000',
+    "conll2000",
     ConllChunkCorpusReader,
-    ['train.txt', 'test.txt'],
-    ('NP', 'VP', 'PP'),
-    tagset='wsj',
-    encoding='ascii',
+    ["train.txt", "test.txt"],
+    ("NP", "VP", "PP"),
+    tagset="wsj",
+    encoding="ascii",
 )
 conll2002 = LazyCorpusLoader(
-    'conll2002',
+    "conll2002",
     ConllChunkCorpusReader,
-    '.*\.(test|train).*',
-    ('LOC', 'PER', 'ORG', 'MISC'),
-    encoding='utf-8',
+    ".*\.(test|train).*",
+    ("LOC", "PER", "ORG", "MISC"),
+    encoding="utf-8",
 )
 conll2007 = LazyCorpusLoader(
-    'conll2007',
+    "conll2007",
     DependencyCorpusReader,
-    '.*\.(test|train).*',
-    encoding=[('eus', 'ISO-8859-2'), ('esp', 'utf8')],
+    ".*\.(test|train).*",
+    encoding=[("eus", "ISO-8859-2"), ("esp", "utf8")],
 )
-crubadan = LazyCorpusLoader('crubadan', CrubadanCorpusReader, '.*\.txt')
+crubadan = LazyCorpusLoader("crubadan", CrubadanCorpusReader, ".*\.txt")
 dependency_treebank = LazyCorpusLoader(
-    'dependency_treebank', DependencyCorpusReader, '.*\.dp', encoding='ascii'
+    "dependency_treebank", DependencyCorpusReader, ".*\.dp", encoding="ascii"
 )
 floresta = LazyCorpusLoader(
-    'floresta',
+    "floresta",
     BracketParseCorpusReader,
-    r'(?!\.).*\.ptb',
-    '#',
-    tagset='unknown',
-    encoding='ISO-8859-15',
+    r"(?!\.).*\.ptb",
+    "#",
+    tagset="unknown",
+    encoding="ISO-8859-15",
 )
 framenet15 = LazyCorpusLoader(
-    'framenet_v15',
+    "framenet_v15",
     FramenetCorpusReader,
     [
-        'frRelation.xml',
-        'frameIndex.xml',
-        'fulltextIndex.xml',
-        'luIndex.xml',
-        'semTypes.xml',
+        "frRelation.xml",
+        "frameIndex.xml",
+        "fulltextIndex.xml",
+        "luIndex.xml",
+        "semTypes.xml",
     ],
 )
 framenet = LazyCorpusLoader(
-    'framenet_v17',
+    "framenet_v17",
     FramenetCorpusReader,
     [
-        'frRelation.xml',
-        'frameIndex.xml',
-        'fulltextIndex.xml',
-        'luIndex.xml',
-        'semTypes.xml',
+        "frRelation.xml",
+        "frameIndex.xml",
+        "fulltextIndex.xml",
+        "luIndex.xml",
+        "semTypes.xml",
     ],
 )
 gazetteers = LazyCorpusLoader(
-    'gazetteers', WordListCorpusReader, r'(?!LICENSE|\.).*\.txt', encoding='ISO-8859-2'
+    "gazetteers", WordListCorpusReader, r"(?!LICENSE|\.).*\.txt", encoding="ISO-8859-2"
 )
 genesis = LazyCorpusLoader(
-    'genesis',
+    "genesis",
     PlaintextCorpusReader,
-    r'(?!\.).*\.txt',
+    r"(?!\.).*\.txt",
     encoding=[
-        ('finnish|french|german', 'latin_1'),
-        ('swedish', 'cp865'),
-        ('.*', 'utf_8'),
+        ("finnish|french|german", "latin_1"),
+        ("swedish", "cp865"),
+        (".*", "utf_8"),
     ],
 )
 gutenberg = LazyCorpusLoader(
-    'gutenberg', PlaintextCorpusReader, r'(?!\.).*\.txt', encoding='latin1'
+    "gutenberg", PlaintextCorpusReader, r"(?!\.).*\.txt", encoding="latin1"
 )
-ieer = LazyCorpusLoader('ieer', IEERCorpusReader, r'(?!README|\.).*')
+ieer = LazyCorpusLoader("ieer", IEERCorpusReader, r"(?!README|\.).*")
 inaugural = LazyCorpusLoader(
-    'inaugural', PlaintextCorpusReader, r'(?!\.).*\.txt', encoding='latin1'
+    "inaugural", PlaintextCorpusReader, r"(?!\.).*\.txt", encoding="latin1"
 )
 # [XX] This should probably just use TaggedCorpusReader:
 indian = LazyCorpusLoader(
-    'indian', IndianCorpusReader, r'(?!\.).*\.pos', tagset='unknown', encoding='utf8'
+    "indian", IndianCorpusReader, r"(?!\.).*\.pos", tagset="unknown", encoding="utf8"
 )
 
-jeita = LazyCorpusLoader('jeita', ChasenCorpusReader, r'.*\.chasen', encoding='utf-8')
-knbc = LazyCorpusLoader('knbc/corpus1', KNBCorpusReader, r'.*/KN.*', encoding='euc-jp')
-lin_thesaurus = LazyCorpusLoader('lin_thesaurus', LinThesaurusCorpusReader, r'.*\.lsp')
+jeita = LazyCorpusLoader("jeita", ChasenCorpusReader, r".*\.chasen", encoding="utf-8")
+knbc = LazyCorpusLoader("knbc/corpus1", KNBCorpusReader, r".*/KN.*", encoding="euc-jp")
+lin_thesaurus = LazyCorpusLoader("lin_thesaurus", LinThesaurusCorpusReader, r".*\.lsp")
 mac_morpho = LazyCorpusLoader(
-    'mac_morpho',
+    "mac_morpho",
     MacMorphoCorpusReader,
-    r'(?!\.).*\.txt',
-    tagset='unknown',
-    encoding='latin-1',
+    r"(?!\.).*\.txt",
+    tagset="unknown",
+    encoding="latin-1",
 )
 machado = LazyCorpusLoader(
-    'machado',
+    "machado",
     PortugueseCategorizedPlaintextCorpusReader,
-    r'(?!\.).*\.txt',
-    cat_pattern=r'([a-z]*)/.*',
-    encoding='latin-1',
+    r"(?!\.).*\.txt",
+    cat_pattern=r"([a-z]*)/.*",
+    encoding="latin-1",
 )
 masc_tagged = LazyCorpusLoader(
-    'masc_tagged',
+    "masc_tagged",
     CategorizedTaggedCorpusReader,
-    r'(spoken|written)/.*\.txt',
-    cat_file='categories.txt',
-    tagset='wsj',
+    r"(spoken|written)/.*\.txt",
+    cat_file="categories.txt",
+    tagset="wsj",
     encoding="utf-8",
     sep="_",
 )
 movie_reviews = LazyCorpusLoader(
-    'movie_reviews',
+    "movie_reviews",
     CategorizedPlaintextCorpusReader,
-    r'(?!\.).*\.txt',
-    cat_pattern=r'(neg|pos)/.*',
-    encoding='ascii',
+    r"(?!\.).*\.txt",
+    cat_pattern=r"(neg|pos)/.*",
+    encoding="ascii",
 )
 multext_east = LazyCorpusLoader(
-    'mte_teip5', MTECorpusReader, r'(oana).*\.xml', encoding="utf-8"
+    "mte_teip5", MTECorpusReader, r"(oana).*\.xml", encoding="utf-8"
 )
 names = LazyCorpusLoader(
-    'names', WordListCorpusReader, r'(?!\.).*\.txt', encoding='ascii'
+    "names", WordListCorpusReader, r"(?!\.).*\.txt", encoding="ascii"
 )
 nps_chat = LazyCorpusLoader(
-    'nps_chat', NPSChatCorpusReader, r'(?!README|\.).*\.xml', tagset='wsj'
+    "nps_chat", NPSChatCorpusReader, r"(?!README|\.).*\.xml", tagset="wsj"
 )
 opinion_lexicon = LazyCorpusLoader(
-    'opinion_lexicon',
+    "opinion_lexicon",
     OpinionLexiconCorpusReader,
-    r'(\w+)\-words\.txt',
-    encoding='ISO-8859-2',
+    r"(\w+)\-words\.txt",
+    encoding="ISO-8859-2",
 )
 ppattach = LazyCorpusLoader(
-    'ppattach', PPAttachmentCorpusReader, ['training', 'test', 'devset']
+    "ppattach", PPAttachmentCorpusReader, ["training", "test", "devset"]
 )
 product_reviews_1 = LazyCorpusLoader(
-    'product_reviews_1', ReviewsCorpusReader, r'^(?!Readme).*\.txt', encoding='utf8'
+    "product_reviews_1", ReviewsCorpusReader, r"^(?!Readme).*\.txt", encoding="utf8"
 )
 product_reviews_2 = LazyCorpusLoader(
-    'product_reviews_2', ReviewsCorpusReader, r'^(?!Readme).*\.txt', encoding='utf8'
+    "product_reviews_2", ReviewsCorpusReader, r"^(?!Readme).*\.txt", encoding="utf8"
 )
 pros_cons = LazyCorpusLoader(
-    'pros_cons',
+    "pros_cons",
     ProsConsCorpusReader,
-    r'Integrated(Cons|Pros)\.txt',
-    cat_pattern=r'Integrated(Cons|Pros)\.txt',
-    encoding='ISO-8859-2',
+    r"Integrated(Cons|Pros)\.txt",
+    cat_pattern=r"Integrated(Cons|Pros)\.txt",
+    encoding="ISO-8859-2",
 )
 ptb = LazyCorpusLoader(  # Penn Treebank v3: WSJ and Brown portions
-    'ptb',
+    "ptb",
     CategorizedBracketParseCorpusReader,
-    r'(WSJ/\d\d/WSJ_\d\d|BROWN/C[A-Z]/C[A-Z])\d\d.MRG',
-    cat_file='allcats.txt',
-    tagset='wsj',
+    r"(WSJ/\d\d/WSJ_\d\d|BROWN/C[A-Z]/C[A-Z])\d\d.MRG",
+    cat_file="allcats.txt",
+    tagset="wsj",
 )
 qc = LazyCorpusLoader(
-    'qc', StringCategoryCorpusReader, ['train.txt', 'test.txt'], encoding='ISO-8859-2'
+    "qc", StringCategoryCorpusReader, ["train.txt", "test.txt"], encoding="ISO-8859-2"
 )
 reuters = LazyCorpusLoader(
-    'reuters',
+    "reuters",
     CategorizedPlaintextCorpusReader,
-    '(training|test).*',
-    cat_file='cats.txt',
-    encoding='ISO-8859-2',
+    "(training|test).*",
+    cat_file="cats.txt",
+    encoding="ISO-8859-2",
 )
-rte = LazyCorpusLoader('rte', RTECorpusReader, r'(?!\.).*\.xml')
-senseval = LazyCorpusLoader('senseval', SensevalCorpusReader, r'(?!\.).*\.pos')
+rte = LazyCorpusLoader("rte", RTECorpusReader, r"(?!\.).*\.xml")
+senseval = LazyCorpusLoader("senseval", SensevalCorpusReader, r"(?!\.).*\.pos")
 sentence_polarity = LazyCorpusLoader(
-    'sentence_polarity',
+    "sentence_polarity",
     CategorizedSentencesCorpusReader,
-    r'rt-polarity\.(neg|pos)',
-    cat_pattern=r'rt-polarity\.(neg|pos)',
-    encoding='utf-8',
+    r"rt-polarity\.(neg|pos)",
+    cat_pattern=r"rt-polarity\.(neg|pos)",
+    encoding="utf-8",
 )
 sentiwordnet = LazyCorpusLoader(
-    'sentiwordnet', SentiWordNetCorpusReader, 'SentiWordNet_3.0.0.txt', encoding='utf-8'
+    "sentiwordnet", SentiWordNetCorpusReader, "SentiWordNet_3.0.0.txt", encoding="utf-8"
 )
-shakespeare = LazyCorpusLoader('shakespeare', XMLCorpusReader, r'(?!\.).*\.xml')
+shakespeare = LazyCorpusLoader("shakespeare", XMLCorpusReader, r"(?!\.).*\.xml")
 sinica_treebank = LazyCorpusLoader(
-    'sinica_treebank',
+    "sinica_treebank",
     SinicaTreebankCorpusReader,
-    ['parsed'],
-    tagset='unknown',
-    encoding='utf-8',
+    ["parsed"],
+    tagset="unknown",
+    encoding="utf-8",
 )
 state_union = LazyCorpusLoader(
-    'state_union', PlaintextCorpusReader, r'(?!\.).*\.txt', encoding='ISO-8859-2'
+    "state_union", PlaintextCorpusReader, r"(?!\.).*\.txt", encoding="ISO-8859-2"
 )
 stopwords = LazyCorpusLoader(
-    'stopwords', WordListCorpusReader, r'(?!README|\.).*', encoding='utf8'
+    "stopwords", WordListCorpusReader, r"(?!README|\.).*", encoding="utf8"
 )
 subjectivity = LazyCorpusLoader(
-    'subjectivity',
+    "subjectivity",
     CategorizedSentencesCorpusReader,
-    r'(quote.tok.gt9|plot.tok.gt9)\.5000',
-    cat_map={'quote.tok.gt9.5000': ['subj'], 'plot.tok.gt9.5000': ['obj']},
-    encoding='latin-1',
+    r"(quote.tok.gt9|plot.tok.gt9)\.5000",
+    cat_map={"quote.tok.gt9.5000": ["subj"], "plot.tok.gt9.5000": ["obj"]},
+    encoding="latin-1",
 )
 swadesh = LazyCorpusLoader(
-    'swadesh', SwadeshCorpusReader, r'(?!README|\.).*', encoding='utf8'
+    "swadesh", SwadeshCorpusReader, r"(?!README|\.).*", encoding="utf8"
 )
 swadesh110 = LazyCorpusLoader(
     'panlex_swadesh', PanlexSwadeshCorpusReader, r'swadesh110/.*\.txt', encoding='utf8'
@@ -305,120 +305,120 @@ swadesh110 = LazyCorpusLoader(
 swadesh207 = LazyCorpusLoader(
     'panlex_swadesh', PanlexSwadeshCorpusReader, r'swadesh207/.*\.txt', encoding='utf8'
 )
-switchboard = LazyCorpusLoader('switchboard', SwitchboardCorpusReader, tagset='wsj')
-timit = LazyCorpusLoader('timit', TimitCorpusReader)
+switchboard = LazyCorpusLoader("switchboard", SwitchboardCorpusReader, tagset="wsj")
+timit = LazyCorpusLoader("timit", TimitCorpusReader)
 timit_tagged = LazyCorpusLoader(
-    'timit', TimitTaggedCorpusReader, '.+\.tags', tagset='wsj', encoding='ascii'
+    "timit", TimitTaggedCorpusReader, ".+\.tags", tagset="wsj", encoding="ascii"
 )
 toolbox = LazyCorpusLoader(
-    'toolbox', ToolboxCorpusReader, r'(?!.*(README|\.)).*\.(dic|txt)'
+    "toolbox", ToolboxCorpusReader, r"(?!.*(README|\.)).*\.(dic|txt)"
 )
 treebank = LazyCorpusLoader(
-    'treebank/combined',
+    "treebank/combined",
     BracketParseCorpusReader,
-    r'wsj_.*\.mrg',
-    tagset='wsj',
-    encoding='ascii',
+    r"wsj_.*\.mrg",
+    tagset="wsj",
+    encoding="ascii",
 )
 treebank_chunk = LazyCorpusLoader(
-    'treebank/tagged',
+    "treebank/tagged",
     ChunkedCorpusReader,
-    r'wsj_.*\.pos',
-    sent_tokenizer=RegexpTokenizer(r'(?<=/\.)\s*(?![^\[]*\])', gaps=True),
+    r"wsj_.*\.pos",
+    sent_tokenizer=RegexpTokenizer(r"(?<=/\.)\s*(?![^\[]*\])", gaps=True),
     para_block_reader=tagged_treebank_para_block_reader,
-    tagset='wsj',
-    encoding='ascii',
+    tagset="wsj",
+    encoding="ascii",
 )
 treebank_raw = LazyCorpusLoader(
-    'treebank/raw', PlaintextCorpusReader, r'wsj_.*', encoding='ISO-8859-2'
+    "treebank/raw", PlaintextCorpusReader, r"wsj_.*", encoding="ISO-8859-2"
 )
-twitter_samples = LazyCorpusLoader('twitter_samples', TwitterCorpusReader, '.*\.json')
-udhr = LazyCorpusLoader('udhr', UdhrCorpusReader)
-udhr2 = LazyCorpusLoader('udhr2', PlaintextCorpusReader, r'.*\.txt', encoding='utf8')
+twitter_samples = LazyCorpusLoader("twitter_samples", TwitterCorpusReader, ".*\.json")
+udhr = LazyCorpusLoader("udhr", UdhrCorpusReader)
+udhr2 = LazyCorpusLoader("udhr2", PlaintextCorpusReader, r".*\.txt", encoding="utf8")
 universal_treebanks = LazyCorpusLoader(
-    'universal_treebanks_v20',
+    "universal_treebanks_v20",
     ConllCorpusReader,
-    r'.*\.conll',
+    r".*\.conll",
     columntypes=(
-        'ignore',
-        'words',
-        'ignore',
-        'ignore',
-        'pos',
-        'ignore',
-        'ignore',
-        'ignore',
-        'ignore',
-        'ignore',
+        "ignore",
+        "words",
+        "ignore",
+        "ignore",
+        "pos",
+        "ignore",
+        "ignore",
+        "ignore",
+        "ignore",
+        "ignore",
     ),
 )
-verbnet = LazyCorpusLoader('verbnet', VerbnetCorpusReader, r'(?!\.).*\.xml')
+verbnet = LazyCorpusLoader("verbnet", VerbnetCorpusReader, r"(?!\.).*\.xml")
 webtext = LazyCorpusLoader(
-    'webtext', PlaintextCorpusReader, r'(?!README|\.).*\.txt', encoding='ISO-8859-2'
+    "webtext", PlaintextCorpusReader, r"(?!README|\.).*\.txt", encoding="ISO-8859-2"
 )
 wordnet = LazyCorpusLoader(
-    'wordnet',
+    "wordnet",
     WordNetCorpusReader,
-    LazyCorpusLoader('omw', CorpusReader, r'.*/wn-data-.*\.tab', encoding='utf8'),
+    LazyCorpusLoader("omw", CorpusReader, r".*/wn-data-.*\.tab", encoding="utf8"),
 )
-wordnet_ic = LazyCorpusLoader('wordnet_ic', WordNetICCorpusReader, '.*\.dat')
+wordnet_ic = LazyCorpusLoader("wordnet_ic", WordNetICCorpusReader, ".*\.dat")
 words = LazyCorpusLoader(
-    'words', WordListCorpusReader, r'(?!README|\.).*', encoding='ascii'
+    "words", WordListCorpusReader, r"(?!README|\.).*", encoding="ascii"
 )
 
 # defined after treebank
 propbank = LazyCorpusLoader(
-    'propbank',
+    "propbank",
     PropbankCorpusReader,
-    'prop.txt',
-    'frames/.*\.xml',
-    'verbs.txt',
-    lambda filename: re.sub(r'^wsj/\d\d/', '', filename),
+    "prop.txt",
+    "frames/.*\.xml",
+    "verbs.txt",
+    lambda filename: re.sub(r"^wsj/\d\d/", "", filename),
     treebank,
 )  # Must be defined *after* treebank corpus.
 nombank = LazyCorpusLoader(
-    'nombank.1.0',
+    "nombank.1.0",
     NombankCorpusReader,
-    'nombank.1.0',
-    'frames/.*\.xml',
-    'nombank.1.0.words',
-    lambda filename: re.sub(r'^wsj/\d\d/', '', filename),
+    "nombank.1.0",
+    "frames/.*\.xml",
+    "nombank.1.0.words",
+    lambda filename: re.sub(r"^wsj/\d\d/", "", filename),
     treebank,
 )  # Must be defined *after* treebank corpus.
 propbank_ptb = LazyCorpusLoader(
-    'propbank',
+    "propbank",
     PropbankCorpusReader,
-    'prop.txt',
-    'frames/.*\.xml',
-    'verbs.txt',
+    "prop.txt",
+    "frames/.*\.xml",
+    "verbs.txt",
     lambda filename: filename.upper(),
     ptb,
 )  # Must be defined *after* ptb corpus.
 nombank_ptb = LazyCorpusLoader(
-    'nombank.1.0',
+    "nombank.1.0",
     NombankCorpusReader,
-    'nombank.1.0',
-    'frames/.*\.xml',
-    'nombank.1.0.words',
+    "nombank.1.0",
+    "frames/.*\.xml",
+    "nombank.1.0.words",
     lambda filename: filename.upper(),
     ptb,
 )  # Must be defined *after* ptb corpus.
 semcor = LazyCorpusLoader(
-    'semcor', SemcorCorpusReader, r'brown./tagfiles/br-.*\.xml', wordnet
+    "semcor", SemcorCorpusReader, r"brown./tagfiles/br-.*\.xml", wordnet
 )  # Must be defined *after* wordnet corpus.
 
 nonbreaking_prefixes = LazyCorpusLoader(
-    'nonbreaking_prefixes',
+    "nonbreaking_prefixes",
     NonbreakingPrefixesCorpusReader,
-    r'(?!README|\.).*',
-    encoding='utf8',
+    r"(?!README|\.).*",
+    encoding="utf8",
 )
 perluniprops = LazyCorpusLoader(
-    'perluniprops',
+    "perluniprops",
     UnicharsCorpusReader,
-    r'(?!README|\.).*',
-    nltk_data_subdir='misc',
-    encoding='utf8',
+    r"(?!README|\.).*",
+    nltk_data_subdir="misc",
+    encoding="utf8",
 )
 
 # mwa_ppdb = LazyCorpusLoader(
@@ -478,7 +478,7 @@ def demo():
 
 #    ycoe.demo()
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # demo()
     pass
 
@@ -489,5 +489,5 @@ def teardown_module(module=None):
 
     for name in dir(nltk.corpus):
         obj = getattr(nltk.corpus, name, None)
-        if isinstance(obj, CorpusReader) and hasattr(obj, '_unload'):
+        if isinstance(obj, CorpusReader) and hasattr(obj, "_unload"):
             obj._unload()
