@@ -1,6 +1,6 @@
 # Natural Language Toolkit: First-Order Tableau Theorem Prover
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Dan Garrette <dhgarrette@gmail.com>
 #
 # URL: <http://nltk.org/>
@@ -9,7 +9,6 @@
 """
 Module for a tableau-based First Order theorem prover.
 """
-from __future__ import print_function, unicode_literals
 
 from nltk.internals import Counter
 
@@ -58,7 +57,7 @@ class TableauProver(Prover):
             result = self._attempt_proof(agenda, set(), set(), debugger)
         except RuntimeError as e:
             if self._assume_false and str(e).startswith(
-                'maximum recursion depth exceeded'
+                "maximum recursion depth exceeded"
             ):
                 result = False
             else:
@@ -66,14 +65,14 @@ class TableauProver(Prover):
                     print(e)
                 else:
                     raise e
-        return (result, '\n'.join(debugger.lines))
+        return (result, "\n".join(debugger.lines))
 
     def _attempt_proof(self, agenda, accessible_vars, atoms, debug):
         (current, context), category = agenda.pop_first()
 
         # if there's nothing left in the agenda, and we haven't closed the path
         if not current:
-            debug.line('AGENDA EMPTY')
+            debug.line("AGENDA EMPTY")
             return False
 
         proof_method = {
@@ -108,7 +107,7 @@ class TableauProver(Prover):
     ):
         # Check if the branch is closed.  Return 'True' if it is
         if (current, True) in atoms:
-            debug.line('CLOSED', 1)
+            debug.line("CLOSED", 1)
             return True
 
         if context:
@@ -131,7 +130,7 @@ class TableauProver(Prover):
     ):
         # Check if the branch is closed.  Return 'True' if it is
         if (current.term, False) in atoms:
-            debug.line('CLOSED', 1)
+            debug.line("CLOSED", 1)
             return True
 
         if context:
@@ -154,7 +153,7 @@ class TableauProver(Prover):
     ):
         # Check if the branch is closed.  Return 'True' if it is
         if (current, True) in atoms:
-            debug.line('CLOSED', 1)
+            debug.line("CLOSED", 1)
             return True
 
         # mark all AllExpressions as 'not exhausted' into the agenda since we are (potentially) adding new accessible vars
@@ -168,7 +167,7 @@ class TableauProver(Prover):
     ):
         # Check if the branch is closed.  Return 'True' if it is
         if (current.term, False) in atoms:
-            debug.line('CLOSED', 1)
+            debug.line("CLOSED", 1)
             return True
 
         # mark all AllExpressions as 'not exhausted' into the agenda since we are (potentially) adding new accessible vars
@@ -184,7 +183,7 @@ class TableauProver(Prover):
         for i, arg in enumerate(args):
             if not TableauProver.is_atom(arg):
                 ctx = f
-                nv = Variable('X%s' % _counter.get())
+                nv = Variable("X%s" % _counter.get())
                 for j, a in enumerate(args):
                     ctx = ctx(VariableExpression(nv)) if i == j else ctx(a)
                 if context:
@@ -192,7 +191,7 @@ class TableauProver(Prover):
                 ctx = LambdaExpression(nv, ctx)
                 agenda.put(arg, ctx)
                 return self._attempt_proof(agenda, accessible_vars, atoms, debug + 1)
-        raise Exception('If this method is called, there must be a non-atomic argument')
+        raise Exception("If this method is called, there must be a non-atomic argument")
 
     def _attempt_proof_n_app(
         self, current, context, agenda, accessible_vars, atoms, debug
@@ -201,7 +200,7 @@ class TableauProver(Prover):
         for i, arg in enumerate(args):
             if not TableauProver.is_atom(arg):
                 ctx = f
-                nv = Variable('X%s' % _counter.get())
+                nv = Variable("X%s" % _counter.get())
                 for j, a in enumerate(args):
                     ctx = ctx(VariableExpression(nv)) if i == j else ctx(a)
                 if context:
@@ -210,7 +209,7 @@ class TableauProver(Prover):
                 ctx = LambdaExpression(nv, -ctx)
                 agenda.put(-arg, ctx)
                 return self._attempt_proof(agenda, accessible_vars, atoms, debug + 1)
-        raise Exception('If this method is called, there must be a non-atomic argument')
+        raise Exception("If this method is called, there must be a non-atomic argument")
 
     def _attempt_proof_n_eq(
         self, current, context, agenda, accessible_vars, atoms, debug
@@ -219,7 +218,7 @@ class TableauProver(Prover):
         # Since 'current' is of type '~(a=b)', the path is closed if 'a' == 'b'
         ###########################################################################
         if current.term.first == current.term.second:
-            debug.line('CLOSED', 1)
+            debug.line("CLOSED", 1)
             return True
 
         agenda[Categories.N_EQ].add((current, context))
@@ -366,7 +365,7 @@ class TableauProver(Prover):
 
             if bv_available:
                 variable_to_use = list(bv_available)[0]
-                debug.line('--> Using \'%s\'' % variable_to_use, 2)
+                debug.line("--> Using '%s'" % variable_to_use, 2)
                 current._used_vars |= set([variable_to_use])
                 agenda.put(
                     current.term.replace(current.variable, variable_to_use), context
@@ -376,14 +375,14 @@ class TableauProver(Prover):
 
             else:
                 # no more available variables to substitute
-                debug.line('--> Variables Exhausted', 2)
+                debug.line("--> Variables Exhausted", 2)
                 current._exhausted = True
                 agenda[Categories.ALL].add((current, context))
                 return self._attempt_proof(agenda, accessible_vars, atoms, debug + 1)
 
         else:
             new_unique_variable = VariableExpression(unique_variable())
-            debug.line('--> Using \'%s\'' % new_unique_variable, 2)
+            debug.line("--> Using '%s'" % new_unique_variable, 2)
             current._used_vars |= set([new_unique_variable])
             agenda.put(
                 current.term.replace(current.variable, new_unique_variable), context
@@ -583,20 +582,20 @@ class Debug(object):
         if isinstance(data, tuple):
             ex, ctx = data
             if ctx:
-                data = '%s, %s' % (ex, ctx)
+                data = "%s, %s" % (ex, ctx)
             else:
-                data = '%s' % ex
+                data = "%s" % ex
 
             if isinstance(ex, AllExpression):
                 try:
                     used_vars = "[%s]" % (
                         ",".join("%s" % ve.variable.name for ve in ex._used_vars)
                     )
-                    data += ':   %s' % used_vars
+                    data += ":   %s" % used_vars
                 except AttributeError:
-                    data += ':   []'
+                    data += ":   []"
 
-        newline = '%s%s' % ('   ' * (self.indent + indent), data)
+        newline = "%s%s" % ("   " * (self.indent + indent), data)
         self.lines.append(newline)
 
         if self.verbose:
@@ -628,49 +627,49 @@ class Categories(object):
 
 
 def testTableauProver():
-    tableau_test('P | -P')
-    tableau_test('P & -P')
-    tableau_test('Q', ['P', '(P -> Q)'])
-    tableau_test('man(x)')
-    tableau_test('(man(x) -> man(x))')
-    tableau_test('(man(x) -> --man(x))')
-    tableau_test('-(man(x) and -man(x))')
-    tableau_test('(man(x) or -man(x))')
-    tableau_test('(man(x) -> man(x))')
-    tableau_test('-(man(x) and -man(x))')
-    tableau_test('(man(x) or -man(x))')
-    tableau_test('(man(x) -> man(x))')
-    tableau_test('(man(x) iff man(x))')
-    tableau_test('-(man(x) iff -man(x))')
-    tableau_test('all x.man(x)')
-    tableau_test('all x.all y.((x = y) -> (y = x))')
-    tableau_test('all x.all y.all z.(((x = y) & (y = z)) -> (x = z))')
+    tableau_test("P | -P")
+    tableau_test("P & -P")
+    tableau_test("Q", ["P", "(P -> Q)"])
+    tableau_test("man(x)")
+    tableau_test("(man(x) -> man(x))")
+    tableau_test("(man(x) -> --man(x))")
+    tableau_test("-(man(x) and -man(x))")
+    tableau_test("(man(x) or -man(x))")
+    tableau_test("(man(x) -> man(x))")
+    tableau_test("-(man(x) and -man(x))")
+    tableau_test("(man(x) or -man(x))")
+    tableau_test("(man(x) -> man(x))")
+    tableau_test("(man(x) iff man(x))")
+    tableau_test("-(man(x) iff -man(x))")
+    tableau_test("all x.man(x)")
+    tableau_test("all x.all y.((x = y) -> (y = x))")
+    tableau_test("all x.all y.all z.(((x = y) & (y = z)) -> (x = z))")
     #    tableau_test('-all x.some y.F(x,y) & some x.all y.(-F(x,y))')
     #    tableau_test('some x.all y.sees(x,y)')
 
-    p1 = 'all x.(man(x) -> mortal(x))'
-    p2 = 'man(Socrates)'
-    c = 'mortal(Socrates)'
+    p1 = "all x.(man(x) -> mortal(x))"
+    p2 = "man(Socrates)"
+    c = "mortal(Socrates)"
     tableau_test(c, [p1, p2])
 
-    p1 = 'all x.(man(x) -> walks(x))'
-    p2 = 'man(John)'
-    c = 'some y.walks(y)'
+    p1 = "all x.(man(x) -> walks(x))"
+    p2 = "man(John)"
+    c = "some y.walks(y)"
     tableau_test(c, [p1, p2])
 
-    p = '((x = y) & walks(y))'
-    c = 'walks(x)'
+    p = "((x = y) & walks(y))"
+    c = "walks(x)"
     tableau_test(c, [p])
 
-    p = '((x = y) & ((y = z) & (z = w)))'
-    c = '(x = w)'
+    p = "((x = y) & ((y = z) & (z = w)))"
+    c = "(x = w)"
     tableau_test(c, [p])
 
-    p = 'some e1.some e2.(believe(e1,john,e2) & walk(e2,mary))'
-    c = 'some e0.walk(e0,mary)'
+    p = "some e1.some e2.(believe(e1,john,e2) & walk(e2,mary))"
+    c = "some e0.walk(e0,mary)"
     tableau_test(c, [p])
 
-    c = '(exists x.exists z3.((x = Mary) & ((z3 = John) & sees(z3,x))) <-> exists x.exists z4.((x = John) & ((z4 = Mary) & sees(x,z4))))'
+    c = "(exists x.exists z3.((x = Mary) & ((z3 = John) & sees(z3,x))) <-> exists x.exists z4.((x = John) & ((z4 = Mary) & sees(x,z4))))"
     tableau_test(c)
 
 
@@ -680,19 +679,19 @@ def testTableauProver():
 
 
 def testHigherOrderTableauProver():
-    tableau_test('believe(j, -lie(b))', ['believe(j, -lie(b) & -cheat(b))'])
-    tableau_test('believe(j, lie(b) & cheat(b))', ['believe(j, lie(b))'])
+    tableau_test("believe(j, -lie(b))", ["believe(j, -lie(b) & -cheat(b))"])
+    tableau_test("believe(j, lie(b) & cheat(b))", ["believe(j, lie(b))"])
     tableau_test(
-        'believe(j, lie(b))', ['lie(b)']
+        "believe(j, lie(b))", ["lie(b)"]
     )  # how do we capture that John believes all things that are true
     tableau_test(
-        'believe(j, know(b, cheat(b)))',
-        ['believe(j, know(b, lie(b)) & know(b, steals(b) & cheat(b)))'],
+        "believe(j, know(b, cheat(b)))",
+        ["believe(j, know(b, lie(b)) & know(b, steals(b) & cheat(b)))"],
     )
-    tableau_test('P(Q(y), R(y) & R(z))', ['P(Q(x) & Q(y), R(y) & R(z))'])
+    tableau_test("P(Q(y), R(y) & R(z))", ["P(Q(x) & Q(y), R(y) & R(z))"])
 
-    tableau_test('believe(j, cheat(b) & lie(b))', ['believe(j, lie(b) & cheat(b))'])
-    tableau_test('believe(j, -cheat(b) & -lie(b))', ['believe(j, -lie(b) & -cheat(b))'])
+    tableau_test("believe(j, cheat(b) & lie(b))", ["believe(j, lie(b) & cheat(b))"])
+    tableau_test("believe(j, -cheat(b) & -lie(b))", ["believe(j, -lie(b) & -cheat(b))"])
 
 
 def tableau_test(c, ps=None, verbose=False):
@@ -701,8 +700,8 @@ def tableau_test(c, ps=None, verbose=False):
     if not ps:
         ps = []
     print(
-        '%s |- %s: %s'
-        % (', '.join(ps), pc, TableauProver().prove(pc, pps, verbose=verbose))
+        "%s |- %s: %s"
+        % (", ".join(ps), pc, TableauProver().prove(pc, pps, verbose=verbose))
     )
 
 
@@ -711,5 +710,5 @@ def demo():
     testHigherOrderTableauProver()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     demo()
