@@ -1,19 +1,18 @@
 # Natural Language Toolkit: Models for first-order languages with lambda
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Ewan Klein <ewan@inf.ed.ac.uk>,
 # URL: <http://nltk.sourceforge.net>
 # For license information, see LICENSE.TXT
 
-#TODO:
-    #- fix tracing
-    #- fix iterator-based approach to existentials
+# TODO:
+# - fix tracing
+# - fix iterator-based approach to existentials
 
 """
 This module provides data structures for representing first-order
 models.
 """
-from __future__ import print_function, unicode_literals
 
 from pprint import pformat
 import inspect
@@ -21,35 +20,45 @@ import textwrap
 import re
 import sys
 
-from six import string_types
+from nltk.decorators import decorator  # this used in code that is commented out
 
-from nltk.decorators import decorator # this used in code that is commented out
-from nltk.compat import python_2_unicode_compatible
-
-from nltk.sem.logic import (AbstractVariableExpression, AllExpression, Expression,
-                            AndExpression, ApplicationExpression, EqualityExpression,
-                            ExistsExpression, IffExpression, ImpExpression,
-                            IndividualVariableExpression, LambdaExpression,
-                            NegatedExpression, OrExpression,
-                            Variable, is_indvar)
+from nltk.sem.logic import (
+    AbstractVariableExpression,
+    AllExpression,
+    Expression,
+    AndExpression,
+    ApplicationExpression,
+    EqualityExpression,
+    ExistsExpression,
+    IffExpression,
+    ImpExpression,
+    IndividualVariableExpression,
+    LambdaExpression,
+    NegatedExpression,
+    OrExpression,
+    Variable,
+    is_indvar,
+)
 
 
-class Error(Exception): pass
+class Error(Exception):
+    pass
+
+
+class Undefined(Error):
+    pass
 
-class Undefined(Error):  pass
 
 def trace(f, *args, **kw):
-    if sys.version_info[0] >= 3:
-        argspec = inspect.getfullargspec(f)
-    else:
-        argspec = inspect.getargspec(f)
+    argspec = inspect.getfullargspec(f)
     d = dict(zip(argspec[0], args))
-    if d.pop('trace', None):
+    if d.pop("trace", None):
         print()
         for item in d.items():
             print("%s => %s" % item)
     return f(*args, **kw)
 
+
 def is_rel(s):
     """
     Check whether a set represents a relation (of any arity).
@@ -62,11 +71,12 @@ def is_rel(s):
     if len(s) == 0:
         return True
     # all the elements are tuples of the same length
-    elif all(isinstance(el, tuple) for el in s) and len(max(s))==len(min(s)):
+    elif all(isinstance(el, tuple) for el in s) and len(max(s)) == len(min(s)):
         return True
     else:
         raise ValueError("Set %r contains sequences of different lengths" % s)
 
+
 def set2rel(s):
     """
     Convert a set containing individuals (strings or numbers) into a set of
@@ -82,14 +92,15 @@ def set2rel(s):
     """
     new = set()
     for elem in s:
-        if isinstance(elem, string_types):
+        if isinstance(elem, str):
             new.add((elem,))
         elif isinstance(elem, int):
-            new.add((str(elem,)))
+            new.add((str(elem)))
         else:
             new.add(elem)
     return new
 
+
 def arity(rel):
     """
     Check the arity of a relation.
@@ -101,7 +112,6 @@ def arity(rel):
     return len(list(rel)[0])
 
 
-@python_2_unicode_compatible
 class Valuation(dict):
     """
     A dictionary which represents a model-theoretic Valuation of non-logical constants.
@@ -113,19 +123,23 @@ class Valuation(dict):
     just behave like a standard  dictionary) if indexed with an expression that
     is not in its list of symbols.
     """
+
     def __init__(self, xs):
         """
         :param xs: a list of (symbol, value) pairs.
         """
         super(Valuation, self).__init__()
         for (sym, val) in xs:
-            if isinstance(val, string_types) or isinstance(val, bool):
+            if isinstance(val, str) or isinstance(val, bool):
                 self[sym] = val
             elif isinstance(val, set):
                 self[sym] = set2rel(val)
             else:
-                msg = textwrap.fill("Error in initializing Valuation. "
-                                    "Unrecognized value for symbol '%s':\n%s" % (sym, val), width=66)
+                msg = textwrap.fill(
+                    "Error in initializing Valuation. "
+                    "Unrecognized value for symbol '%s':\n%s" % (sym, val),
+                    width=66,
+                )
 
                 raise ValueError(msg)
 
@@ -143,10 +157,12 @@ class Valuation(dict):
         """Set-theoretic domain of the value-space of a Valuation."""
         dom = []
         for val in self.values():
-            if isinstance(val, string_types):
+            if isinstance(val, str):
                 dom.append(val)
             elif not isinstance(val, bool):
-                dom.extend([elem for tuple_ in val for elem in tuple_ if elem is not None])
+                dom.extend(
+                    [elem for tuple_ in val for elem in tuple_ if elem is not None]
+                )
         return set(dom)
 
     @property
@@ -162,11 +178,15 @@ class Valuation(dict):
 ##########################################
 # REs used by the _read_valuation function
 ##########################################
-_VAL_SPLIT_RE = re.compile(r'\s*=+>\s*')
-_ELEMENT_SPLIT_RE = re.compile(r'\s*,\s*')
-_TUPLES_RE = re.compile(r"""\s*
+_VAL_SPLIT_RE = re.compile(r"\s*=+>\s*")
+_ELEMENT_SPLIT_RE = re.compile(r"\s*,\s*")
+_TUPLES_RE = re.compile(
+    r"""\s*
                                 (\([^)]+\))  # tuple-expression
-                                \s*""", re.VERBOSE)
+                                \s*""",
+    re.VERBOSE,
+)
+
 
 def _read_valuation_line(s):
     """
@@ -187,7 +207,7 @@ def _read_valuation_line(s):
     symbol = pieces[0]
     value = pieces[1]
     # check whether the value is meant to be a set
-    if value.startswith('{'):
+    if value.startswith("{"):
         value = value[1:-1]
         tuple_strings = _TUPLES_RE.findall(value)
         # are the set elements tuples?
@@ -202,6 +222,7 @@ def _read_valuation_line(s):
         value = set(set_elements)
     return symbol, value
 
+
 def read_valuation(s, encoding=None):
     """
     Convert a valuation string into a valuation.
@@ -218,15 +239,15 @@ def read_valuation(s, encoding=None):
     statements = []
     for linenum, line in enumerate(s.splitlines()):
         line = line.strip()
-        if line.startswith('#') or line=='': continue
+        if line.startswith("#") or line == "":
+            continue
         try:
             statements.append(_read_valuation_line(line))
         except ValueError:
-            raise ValueError('Unable to parse line %s: %s' % (linenum, line))
+            raise ValueError("Unable to parse line %s: %s" % (linenum, line))
     return Valuation(statements)
 
 
-@python_2_unicode_compatible
 class Assignment(dict):
     """
     A dictionary which represents an assignment of values to variables.
@@ -285,10 +306,13 @@ class Assignment(dict):
         self.domain = domain
         if assign:
             for (var, val) in assign:
-                assert val in self.domain,\
-                       "'%s' is not in the domain: %s" % (val, self.domain)
-                assert is_indvar(var),\
-                       "Wrong format for an Individual Variable: '%s'" % var
+                assert val in self.domain, "'%s' is not in the domain: %s" % (
+                    val,
+                    self.domain,
+                )
+                assert is_indvar(var), (
+                    "Wrong format for an Individual Variable: '%s'" % var
+                )
                 self[var] = val
         self.variant = None
         self._addvariant()
@@ -346,16 +370,13 @@ class Assignment(dict):
         ``self.variant``.
 
         """
-        assert val in self.domain,\
-               "%s is not in the domain %s" % (val, self.domain)
-        assert is_indvar(var),\
-               "Wrong format for an Individual Variable: '%s'" % var
+        assert val in self.domain, "%s is not in the domain %s" % (val, self.domain)
+        assert is_indvar(var), "Wrong format for an Individual Variable: '%s'" % var
         self[var] = val
         self._addvariant()
         return self
 
 
-@python_2_unicode_compatible
 class Model(object):
     """
     A first order model is a domain *D* of discourse and a valuation *V*.
@@ -379,8 +400,10 @@ class Model(object):
         self.domain = domain
         self.valuation = valuation
         if not domain.issuperset(valuation.domain):
-            raise Error("The valuation domain, %s, must be a subset of the model's domain, %s"\
-                  % (valuation.domain, domain))
+            raise Error(
+                "The valuation domain, %s, must be a subset of the model's domain, %s"
+                % (valuation.domain, domain)
+            )
 
     def __repr__(self):
         return "(%r, %r)" % (self.domain, self.valuation)
@@ -402,14 +425,13 @@ class Model(object):
             value = self.satisfy(parsed, g, trace=trace)
             if trace:
                 print()
-                print("'%s' evaluates to %s under M, %s" %  (expr, value, g))
+                print("'%s' evaluates to %s under M, %s" % (expr, value, g))
             return value
         except Undefined:
             if trace:
                 print()
-                print("'%s' is undefined under M, %s" %  (expr, g))
-            return 'Undefined'
-
+                print("'%s' is undefined under M, %s" % (expr, g))
+            return "Undefined"
 
     def satisfy(self, parsed, g, trace=None):
         """
@@ -430,32 +452,27 @@ class Model(object):
         if isinstance(parsed, ApplicationExpression):
             function, arguments = parsed.uncurry()
             if isinstance(function, AbstractVariableExpression):
-                #It's a predicate expression ("P(x,y)"), so used uncurried arguments
+                # It's a predicate expression ("P(x,y)"), so used uncurried arguments
                 funval = self.satisfy(function, g)
                 argvals = tuple(self.satisfy(arg, g) for arg in arguments)
                 return argvals in funval
             else:
-                #It must be a lambda expression, so use curried form
+                # It must be a lambda expression, so use curried form
                 funval = self.satisfy(parsed.function, g)
                 argval = self.satisfy(parsed.argument, g)
                 return funval[argval]
         elif isinstance(parsed, NegatedExpression):
             return not self.satisfy(parsed.term, g)
         elif isinstance(parsed, AndExpression):
-            return self.satisfy(parsed.first, g) and \
-                   self.satisfy(parsed.second, g)
+            return self.satisfy(parsed.first, g) and self.satisfy(parsed.second, g)
         elif isinstance(parsed, OrExpression):
-            return self.satisfy(parsed.first, g) or \
-                   self.satisfy(parsed.second, g)
+            return self.satisfy(parsed.first, g) or self.satisfy(parsed.second, g)
         elif isinstance(parsed, ImpExpression):
-            return (not self.satisfy(parsed.first, g)) or \
-                   self.satisfy(parsed.second, g)
+            return (not self.satisfy(parsed.first, g)) or self.satisfy(parsed.second, g)
         elif isinstance(parsed, IffExpression):
-            return self.satisfy(parsed.first, g) == \
-                   self.satisfy(parsed.second, g)
+            return self.satisfy(parsed.first, g) == self.satisfy(parsed.second, g)
         elif isinstance(parsed, EqualityExpression):
-            return self.satisfy(parsed.first, g) == \
-                   self.satisfy(parsed.second, g)
+            return self.satisfy(parsed.first, g) == self.satisfy(parsed.second, g)
         elif isinstance(parsed, AllExpression):
             new_g = g.copy()
             for u in self.domain:
@@ -484,7 +501,7 @@ class Model(object):
         else:
             return self.i(parsed, g, trace)
 
-    #@decorator(trace_eval)
+    # @decorator(trace_eval)
     def i(self, parsed, g, trace=False):
         """
         An interpretation function.
@@ -524,11 +541,11 @@ class Model(object):
         :return: a set of the entities that satisfy ``parsed``.
         """
 
-        spacer = '   '
+        spacer = "   "
         indent = spacer + (spacer * nesting)
         candidates = []
 
-        if isinstance(varex, string_types):
+        if isinstance(varex, str):
             var = Variable(varex)
         else:
             var = varex
@@ -536,12 +553,15 @@ class Model(object):
         if var in parsed.free():
             if trace:
                 print()
-                print((spacer * nesting) + "Open formula is '%s' with assignment %s" % (parsed, g))
+                print(
+                    (spacer * nesting)
+                    + "Open formula is '%s' with assignment %s" % (parsed, g)
+                )
             for u in self.domain:
                 new_g = g.copy()
                 new_g.add(var.name, u)
                 if trace and trace > 1:
-                    lowtrace = trace-1
+                    lowtrace = trace - 1
                 else:
                     lowtrace = 0
                 value = self.satisfy(parsed, new_g, lowtrace)
@@ -552,13 +572,18 @@ class Model(object):
                 # parsed == False under g[u/var]?
                 if value == False:
                     if trace:
-                        print(indent + "value of '%s' under %s is False" % (parsed, new_g))
+                        print(
+                            indent + "value of '%s' under %s is False" % (parsed, new_g)
+                        )
 
                 # so g[u/var] is a satisfying assignment
                 else:
                     candidates.append(u)
                     if trace:
-                        print(indent + "value of '%s' under %s is %s" % (parsed, new_g, value))
+                        print(
+                            indent
+                            + "value of '%s' under %s is %s" % (parsed, new_g, value)
+                        )
 
             result = set(c for c in candidates)
         # var isn't free in parsed
@@ -568,12 +593,9 @@ class Model(object):
         return result
 
 
-
-
-
-#//////////////////////////////////////////////////////////////////////
+# //////////////////////////////////////////////////////////////////////
 # Demo..
-#//////////////////////////////////////////////////////////////////////
+# //////////////////////////////////////////////////////////////////////
 # number of spacer chars
 mult = 30
 
@@ -583,37 +605,37 @@ def propdemo(trace=None):
     """Example of a propositional model."""
 
     global val1, dom1, m1, g1
-    val1 = Valuation([('P', True), ('Q', True), ('R', False)])
+    val1 = Valuation([("P", True), ("Q", True), ("R", False)])
     dom1 = set([])
     m1 = Model(dom1, val1)
     g1 = Assignment(dom1)
 
     print()
-    print('*' * mult)
+    print("*" * mult)
     print("Propositional Formulas Demo")
-    print('*' * mult)
-    print('(Propositional constants treated as nullary predicates)')
+    print("*" * mult)
+    print("(Propositional constants treated as nullary predicates)")
     print()
     print("Model m1:\n", m1)
-    print('*' * mult)
+    print("*" * mult)
     sentences = [
-    '(P & Q)',
-    '(P & R)',
-    '- P',
-    '- R',
-    '- - P',
-    '- (P & R)',
-    '(P | R)',
-    '(R | P)',
-    '(R | R)',
-    '(- P | R)',
-    '(P | - P)',
-    '(P -> Q)',
-    '(P -> R)',
-    '(R -> P)',
-    '(P <-> P)',
-    '(R <-> R)',
-    '(P <-> R)',
+        "(P & Q)",
+        "(P & R)",
+        "- P",
+        "- R",
+        "- - P",
+        "- (P & R)",
+        "(P | R)",
+        "(R | P)",
+        "(R | R)",
+        "(- P | R)",
+        "(P | - P)",
+        "(P -> Q)",
+        "(P -> R)",
+        "(R -> P)",
+        "(P <-> P)",
+        "(R <-> R)",
+        "(P <-> R)",
     ]
 
     for sent in sentences:
@@ -623,42 +645,57 @@ def propdemo(trace=None):
         else:
             print("The value of '%s' is: %s" % (sent, m1.evaluate(sent, g1)))
 
+
 # Demo 2: FOL Model
 #############
 
+
 def folmodel(quiet=False, trace=None):
     """Example of a first-order model."""
 
     global val2, v2, dom2, m2, g2
 
-    v2 = [('adam', 'b1'), ('betty', 'g1'), ('fido', 'd1'),\
-         ('girl', set(['g1', 'g2'])), ('boy', set(['b1', 'b2'])), ('dog', set(['d1'])),
-         ('love', set([('b1', 'g1'), ('b2', 'g2'), ('g1', 'b1'), ('g2', 'b1')]))]
+    v2 = [
+        ("adam", "b1"),
+        ("betty", "g1"),
+        ("fido", "d1"),
+        ("girl", set(["g1", "g2"])),
+        ("boy", set(["b1", "b2"])),
+        ("dog", set(["d1"])),
+        ("love", set([("b1", "g1"), ("b2", "g2"), ("g1", "b1"), ("g2", "b1")])),
+    ]
     val2 = Valuation(v2)
     dom2 = val2.domain
     m2 = Model(dom2, val2)
-    g2 = Assignment(dom2, [('x', 'b1'), ('y', 'g2')])
+    g2 = Assignment(dom2, [("x", "b1"), ("y", "g2")])
 
     if not quiet:
         print()
-        print('*' * mult)
+        print("*" * mult)
         print("Models Demo")
         print("*" * mult)
-        print("Model m2:\n", "-" * 14,"\n", m2)
+        print("Model m2:\n", "-" * 14, "\n", m2)
         print("Variable assignment = ", g2)
 
-        exprs = ['adam', 'boy', 'love', 'walks', 'x', 'y', 'z']
+        exprs = ["adam", "boy", "love", "walks", "x", "y", "z"]
         parsed_exprs = [Expression.fromstring(e) for e in exprs]
 
         print()
         for parsed in parsed_exprs:
             try:
-                print("The interpretation of '%s' in m2 is %s" % (parsed, m2.i(parsed, g2)))
+                print(
+                    "The interpretation of '%s' in m2 is %s"
+                    % (parsed, m2.i(parsed, g2))
+                )
             except Undefined:
                 print("The interpretation of '%s' in m2 is Undefined" % parsed)
 
-
-        applications = [('boy', ('adam')), ('walks', ('adam',)), ('love', ('adam', 'y')), ('love', ('y', 'adam'))]
+        applications = [
+            ("boy", ("adam")),
+            ("walks", ("adam",)),
+            ("love", ("adam", "y")),
+            ("love", ("y", "adam")),
+        ]
 
         for (fun, args) in applications:
             try:
@@ -668,9 +705,11 @@ def folmodel(quiet=False, trace=None):
             except Undefined:
                 print("%s(%s) evaluates to Undefined" % (fun, args))
 
+
 # Demo 3: FOL
 #########
 
+
 def foldemo(trace=None):
     """
     Interpretation of closed expressions in a first-order model.
@@ -678,32 +717,31 @@ def foldemo(trace=None):
     folmodel(quiet=True)
 
     print()
-    print('*' * mult)
+    print("*" * mult)
     print("FOL Formulas Demo")
-    print('*' * mult)
+    print("*" * mult)
 
     formulas = [
-    'love (adam, betty)',
-    '(adam = mia)',
-    '\\x. (boy(x) | girl(x))',
-    '\\x. boy(x)(adam)',
-    '\\x y. love(x, y)',
-    '\\x y. love(x, y)(adam)(betty)',
-    '\\x y. love(x, y)(adam, betty)',
-    '\\x y. (boy(x) & love(x, y))',
-    '\\x. exists y. (boy(x) & love(x, y))',
-    'exists z1. boy(z1)',
-    'exists x. (boy(x) &  -(x = adam))',
-    'exists x. (boy(x) & all y. love(y, x))',
-    'all x. (boy(x) | girl(x))',
-    'all x. (girl(x) -> exists y. boy(y) & love(x, y))',    #Every girl loves exists boy.
-    'exists x. (boy(x) & all y. (girl(y) -> love(y, x)))',  #There is exists boy that every girl loves.
-    'exists x. (boy(x) & all y. (girl(y) -> love(x, y)))',  #exists boy loves every girl.
-    'all x. (dog(x) -> - girl(x))',
-    'exists x. exists y. (love(x, y) & love(x, y))'
+        "love (adam, betty)",
+        "(adam = mia)",
+        "\\x. (boy(x) | girl(x))",
+        "\\x. boy(x)(adam)",
+        "\\x y. love(x, y)",
+        "\\x y. love(x, y)(adam)(betty)",
+        "\\x y. love(x, y)(adam, betty)",
+        "\\x y. (boy(x) & love(x, y))",
+        "\\x. exists y. (boy(x) & love(x, y))",
+        "exists z1. boy(z1)",
+        "exists x. (boy(x) &  -(x = adam))",
+        "exists x. (boy(x) & all y. love(y, x))",
+        "all x. (boy(x) | girl(x))",
+        "all x. (girl(x) -> exists y. boy(y) & love(x, y))",  # Every girl loves exists boy.
+        "exists x. (boy(x) & all y. (girl(y) -> love(y, x)))",  # There is exists boy that every girl loves.
+        "exists x. (boy(x) & all y. (girl(y) -> love(x, y)))",  # exists boy loves every girl.
+        "all x. (dog(x) -> - girl(x))",
+        "exists x. exists y. (love(x, y) & love(x, y))",
     ]
 
-
     for fmla in formulas:
         g2.purge()
         if trace:
@@ -715,37 +753,38 @@ def foldemo(trace=None):
 # Demo 3: Satisfaction
 #############
 
+
 def satdemo(trace=None):
     """Satisfiers of an open formula in a first order model."""
 
     print()
-    print('*' * mult)
+    print("*" * mult)
     print("Satisfiers Demo")
-    print('*' * mult)
+    print("*" * mult)
 
     folmodel(quiet=True)
 
     formulas = [
-               'boy(x)',
-               '(x = x)',
-               '(boy(x) | girl(x))',
-               '(boy(x) & girl(x))',
-               'love(adam, x)',
-               'love(x, adam)',
-               '-(x = adam)',
-               'exists z22. love(x, z22)',
-               'exists y. love(y, x)',
-               'all y. (girl(y) -> love(x, y))',
-               'all y. (girl(y) -> love(y, x))',
-               'all y. (girl(y) -> (boy(x) & love(y, x)))',
-               '(boy(x) & all y. (girl(y) -> love(x, y)))',
-               '(boy(x) & all y. (girl(y) -> love(y, x)))',
-               '(boy(x) & exists y. (girl(y) & love(y, x)))',
-               '(girl(x) -> dog(x))',
-               'all y. (dog(y) -> (x = y))',
-               'exists y. love(y, x)',
-               'exists y. (love(adam, y) & love(y, x))'
-                ]
+        "boy(x)",
+        "(x = x)",
+        "(boy(x) | girl(x))",
+        "(boy(x) & girl(x))",
+        "love(adam, x)",
+        "love(x, adam)",
+        "-(x = adam)",
+        "exists z22. love(x, z22)",
+        "exists y. love(y, x)",
+        "all y. (girl(y) -> love(x, y))",
+        "all y. (girl(y) -> love(y, x))",
+        "all y. (girl(y) -> (boy(x) & love(y, x)))",
+        "(boy(x) & all y. (girl(y) -> love(x, y)))",
+        "(boy(x) & all y. (girl(y) -> love(y, x)))",
+        "(boy(x) & exists y. (girl(y) & love(y, x)))",
+        "(girl(x) -> dog(x))",
+        "all y. (dog(y) -> (x = y))",
+        "exists y. love(y, x)",
+        "exists y. (love(adam, y) & love(y, x))",
+    ]
 
     if trace:
         print(m2)
@@ -758,7 +797,7 @@ def satdemo(trace=None):
 
     for p in parsed:
         g2.purge()
-        print("The satisfiers of '%s' are: %s" % (p, m2.satisfiers(p, 'x', g2, trace)))
+        print("The satisfiers of '%s' are: %s" % (p, m2.satisfiers(p, "x", g2, trace)))
 
 
 def demo(num=0, trace=None):
@@ -773,11 +812,7 @@ def demo(num=0, trace=None):
 
     :param trace: trace = 1, or trace = 2 for more verbose tracing
     """
-    demos = {
-        1: propdemo,
-        2: folmodel,
-        3: foldemo,
-        4: satdemo}
+    demos = {1: propdemo, 2: folmodel, 3: foldemo, 4: satdemo}
 
     try:
         demos[num](trace=trace)
