@@ -2,7 +2,7 @@
 #
 # Natural Language Toolkit: Sentiment Analyzer
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Pierpaolo Pantone <24alsecondo@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -13,22 +13,26 @@ using NLTK features and classifiers, especially for teaching and demonstrative
 purposes.
 """
 
-from __future__ import print_function
+import sys
 from collections import defaultdict
 
 from nltk.classify.util import apply_features, accuracy as eval_accuracy
 from nltk.collocations import BigramCollocationFinder
-from nltk.metrics import (BigramAssocMeasures, precision as eval_precision,
-    recall as eval_recall, f_measure as eval_f_measure)
+from nltk.metrics import (
+    BigramAssocMeasures,
+    precision as eval_precision,
+    recall as eval_recall,
+    f_measure as eval_f_measure,
+)
 
 from nltk.probability import FreqDist
 
-from nltk.sentiment.util import save_file, timer
 
 class SentimentAnalyzer(object):
     """
     A Sentiment Analysis tool based on machine learning approaches.
     """
+
     def __init__(self, classifier=None):
         self.feat_extractors = defaultdict(list)
         self.classifier = classifier
@@ -82,11 +86,15 @@ class SentimentAnalyzer(object):
         """
         # Stopwords are not removed
         unigram_feats_freqs = FreqDist(word for word in words)
-        return [w for w, f in unigram_feats_freqs.most_common(top_n)
-                if unigram_feats_freqs[w] > min_freq]
+        return [
+            w
+            for w, f in unigram_feats_freqs.most_common(top_n)
+            if unigram_feats_freqs[w] > min_freq
+        ]
 
-    def bigram_collocation_feats(self, documents, top_n=None, min_freq=3,
-                                 assoc_measure=BigramAssocMeasures.pmi):
+    def bigram_collocation_feats(
+        self, documents, top_n=None, min_freq=3, assoc_measure=BigramAssocMeasures.pmi
+    ):
         """
         Return `top_n` bigram features (using `assoc_measure`).
         Note that this method is based on bigram collocations measures, and not
@@ -167,17 +175,34 @@ class SentimentAnalyzer(object):
         :param kwargs: additional parameters that will be passed as arguments to
             the classifier `train` function.
         :return: A classifier instance trained on the training set.
-        :rtype: 
+        :rtype:
         """
         print("Training classifier")
         self.classifier = trainer(training_set, **kwargs)
         if save_classifier:
-            save_file(self.classifier, save_classifier)
+            self.save_file(self.classifier, save_classifier)
 
         return self.classifier
 
-    def evaluate(self, test_set, classifier=None, accuracy=True, f_measure=True,
-                 precision=True, recall=True, verbose=False):
+    def save_file(self, content, filename):
+        """
+        Store `content` in `filename`. Can be used to store a SentimentAnalyzer.
+        """
+        print("Saving", filename, file=sys.stderr)
+        with open(filename, 'wb') as storage_file:
+            # The protocol=2 parameter is for python2 compatibility
+            pickle.dump(content, storage_file, protocol=2)
+
+    def evaluate(
+        self,
+        test_set,
+        classifier=None,
+        accuracy=True,
+        f_measure=True,
+        precision=True,
+        recall=True,
+        verbose=False,
+    ):
         """
         Evaluate and print classifier performance on the test set.
 
@@ -196,7 +221,7 @@ class SentimentAnalyzer(object):
         metrics_results = {}
         if accuracy == True:
             accuracy_score = eval_accuracy(classifier, test_set)
-            metrics_results['Accuracy'] = accuracy_score
+            metrics_results["Accuracy"] = accuracy_score
 
         gold_results = defaultdict(set)
         test_results = defaultdict(set)
@@ -209,21 +234,22 @@ class SentimentAnalyzer(object):
 
         for label in labels:
             if precision == True:
-                precision_score = eval_precision(gold_results[label],
-                    test_results[label])
-                metrics_results['Precision [{0}]'.format(label)] = precision_score
+                precision_score = eval_precision(
+                    gold_results[label], test_results[label]
+                )
+                metrics_results["Precision [{0}]".format(label)] = precision_score
             if recall == True:
-                recall_score = eval_recall(gold_results[label],
-                    test_results[label])
-                metrics_results['Recall [{0}]'.format(label)] = recall_score
+                recall_score = eval_recall(gold_results[label], test_results[label])
+                metrics_results["Recall [{0}]".format(label)] = recall_score
             if f_measure == True:
-                f_measure_score = eval_f_measure(gold_results[label],
-                    test_results[label])
-                metrics_results['F-measure [{0}]'.format(label)] = f_measure_score
+                f_measure_score = eval_f_measure(
+                    gold_results[label], test_results[label]
+                )
+                metrics_results["F-measure [{0}]".format(label)] = f_measure_score
 
         # Print evaluation results (in alphabetical order)
         if verbose == True:
             for result in sorted(metrics_results):
-                print('{0}: {1}'.format(result, metrics_results[result]))
+                print("{0}: {1}".format(result, metrics_results[result]))
 
         return metrics_results
